December 2015 Decisions

Advanced Decision Search
Home Court Decisions December 2015 Decisions
December 17, 2015
Decision List | PDF |  | Entries for Cases and Motions
No. 206 | PDF | WPD | The People v. Victor Soto
No. 199 | PDF | WPD | The People v. Anthony V. Pavone
No. 196 | PDF | WPD | The People v. Todd Holley
No. 195 | PDF | WPD | The People v. Kaity Marshall
No. 193 | PDF | WPD | The People v. Natanael Sagastumeal Varenga
No. 178 | PDF | WPD | The People v. Mark Jurgins
December 16, 2015
Decision List | PDF |  | Entries for Cases and Motions
No. 201 | PDF | WPD | The People v. Luis Ortiz
No. 200 | PDF | WPD | Rita Cusimano v. Andrew V. Schnurr Bernard V. Strianese
No. 198 | PDF | WPD | The Matter of Ricardo Suarez v. Melissa Williams
No. 191 and 192 | PDF | WPD | The People v. Luciano Rosario, The People v. Marcos Llibre
No. 163 | PDF | WPD | Edwin Davis v. South Nassau Communities
December 15, 2015
Decision List | PDF |  | Entries for Cases and Motions
No. 214 | PDF | WPD | Doctor Fred L. Pasternack v. Laboratory Corporation of America Holdings
| No. 213 SSM 28 | PDF | WPD | Steven C. Ridge v. Alice Gold
No. 212 SSM 23 | PDF | WPD | The People v. Karl Chu-Joi
No. 202 | PDF | WPD | Matter of RAM I LLC v. New York State Division of Housing and Community Renewal
No. 197 | PDF | WPD | The People v. Dennis P. Smalls
No. 153 | PDF | WPD | Pegasus Aviation I, Inc. v. Varig Logistica S.A.
No. 131 | PDF | WPD | The Ministers and Missionaries Benefit Board v. Leon Snow v. The Estate of Clark Flesher